import * as React from 'react';

export interface MarkProps {
  key: string
  content: string
  start: number
  end: number
  tag: string
  display: string
  wordsToBold?:Array<string>
  special_label?: string
  color?: string
  onClick: (any) => any
}

const style = {
    webkitTouchCallout: 'none', /* iOS Safari */
    webkitUserSelect: 'none', /* Safari */
    khtmlUserSelect: 'none', /* Konqueror HTML */
    mozUserSelect: 'none', /* Old versions of Firefox */
    msUserSelect: 'none', /* Internet Explorer/Edge */
    userSelect: 'none', /* Non-prefixed version, currently
                                  supported by Chrome, Opera and Firefox */
}

const tagSpecial = (special_label,tag) => {
  if(tag === "reference"){
    return `Referência - ${special_label}`;
  }
  if(special_label === "" || special_label === undefined) {
    return tag;
  } else {
    return special_label;
  }
}

const Mark: React.SFC<MarkProps> = props => {

  let bgColor = '#84d2ff';

  if (props.tag === 'reference'){
    bgColor = '#00000057'
  } else if(props.color){
    bgColor = props.color;
  }

  var fore = 'black'

  if(props.color){
    var rgb = [parseInt(props.color.substring(1,3),16),parseInt(props.color.substring(3,5),16),parseInt(props.color.substring(5,7),16)]
    var o = Math.round((rgb[0] * 299) +
    (rgb[1] * 587) +
    (rgb[2] * 114) / 1000);
    fore = (o > 125) ? 'black' : 'white';
  }
  
  return (
  <mark
    style={{backgroundColor: bgColor, padding: '0 4px', color: fore }}
    data-start={props.start}
    data-end={props.end}
    onClick={() => props.onClick({start: props.start, end: props.end})}
  >
    {props.content}
    {props.tag && (
      <span style={{fontSize: '0.7em', fontWeight: 500, marginLeft: 6,...style}}>{tagSpecial(props.special_label,props.tag)}</span>
    )}
  </mark>
)}

export default Mark
